@@ -1,10 +1,13 @@
-from torch.nn import LeakyReLU, GELU, ELU, ReLU, CrossEntropyLoss, L1Loss, MSELoss, BCELoss, BCEWithLogitsLoss, Mish
+from typing import Dict
+
+from torch.nn import LeakyReLU, GELU, ELU, ReLU, CrossEntropyLoss, L1Loss, MSELoss, BCELoss, BCEWithLogitsLoss, Mish, \
+    Module
 
 
 class StringGetter:
     """Util class for retrieve module class from string"""
 
-    _activation_mapping = {
+    _activation_mapping: Dict[str, Module] = {
         "LEAKYRELU": LeakyReLU,
         "GELU": GELU,
         "ELU": ELU,
@@ -12,7 +15,7 @@ class StringGetter:
         "MISH": Mish,
     }
 
-    _loss_mapping = {
+    _loss_mapping: Dict[str, Module] = {
         "CROSSENTROPYLOSS": CrossEntropyLoss,
         "L1LOSS": L1Loss,
         "MSELOSS": MSELoss,
@@ -20,20 +23,20 @@ class StringGetter:
         "BCEWITHLOGITSLOSS": BCEWithLogitsLoss
     }
 
-    _mapping = {
+    _mapping: Dict[str, Dict[str, Module]] = {
         "activation": _activation_mapping,
         "loss": _loss_mapping
     }
 
     def __init__(self, type: str):
         self.type = type
-        self._mapping = StringGetter._mapping[self.type]
+        self.dict = StringGetter._mapping[self.type]
 
     def __call__(self, name: str):
         return self._get(name)
 
     def _get(self, name: str):
-        return self._mapping[name.upper()]
+        return self.dict[name.upper()]
 
 
 get_activation = StringGetter("activation")
